@@ -69,7 +69,7 @@ sub new {
 
 	my $bSizer2 = Wx::BoxSizer->new( Wx::wxVERTICAL );
 	$bSizer2->Add( $m_staticText1, 0, Wx::wxALL, 5 );
-	$bSizer2->AddSpacer(5);
+	$bSizer2->Add( 10, 5, 1, Wx::wxEXPAND, 5 );
 	$bSizer2->Add( $self->{m_button1}, 0, Wx::wxALL, 5 );
 	$bSizer2->Add( $m_staticline1, 0, Wx::wxEXPAND | Wx::wxALL, 5 );
 	$bSizer2->Add( $self->{m_choice1}, 0, Wx::wxALL, 5 );
@@ -79,7 +79,8 @@ sub new {
 	$bSizer1->Add( $bSizer2, 1, Wx::wxEXPAND, 5 );
 
 	$self->SetSizer($bSizer1);
-	$bSizer1->SetSizeHints($self);
+	$self->Layout;
+	$bSizer1->Fit($self);
 
 	return $self;
 }
